@@ -9,8 +9,9 @@
 --   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 --   GNU General Public License for more details.
 
+-- Place Ruins at the location of the destroyed city.
 function city_destroyed_callback(city, loser, destroyer)
-  create_base(city.tile, "Ruins", NIL)
+  city.tile:create_base("Ruins", NIL)
   -- continue processing
   return false
 end
